pub unsafe extern "C" fn vmaCreateBufferWithAlignment(
    allocator: VmaAllocator,
    pBufferCreateInfo: *const BufferCreateInfo,
    pAllocationCreateInfo: *const VmaAllocationCreateInfo,
    minAlignment: DeviceSize,
    pBuffer: *mut Buffer,
    pAllocation: *mut VmaAllocation,
    pAllocationInfo: *mut VmaAllocationInfo
) -> Result
\brief Creates a buffer with additional minimum alignment.

Similar to vmaCreateBuffer() but provides additional parameter minAlignment which allows to specify custom, minimum alignment to be used when placing the buffer inside a larger memory block, which may be needed e.g. for interop with OpenGL.