#[repr(C)]
pub struct VmaVirtualBlockCreateInfo { pub size: DeviceSize, pub flags: VmaVirtualBlockCreateFlags, pub pAllocationCallbacks: *const AllocationCallbacks, }
Parameters of created #VmaVirtualBlock object to be passed to vmaCreateVirtualBlock().

Fields

size: DeviceSize

\brief Total size of the virtual block.

Sizes can be expressed in bytes or any units you want as long as you are consistent in using them. For example, if you allocate from some array of structures, 1 can mean single instance of entire structure.

flags: VmaVirtualBlockCreateFlags

\brief Use combination of #VmaVirtualBlockCreateFlagBits.

pAllocationCallbacks: *const AllocationCallbacks

\brief Custom CPU memory allocation callbacks. Optional.

Optional, can be null. When specified, they will be used for all CPU-side memory allocations.